body
{
   color: #333333;
   font-family: Century Gothic, sans-serif;
   margin-left:3em;
   margin-right:3em;
}

.error
{
   color:red;font-weight:bold;
}

.hidden
{
   display:none;
}

h1
{
  border:1px solid #000; 
  padding:0.5em;
  text-align:center;
}

.result, .zoomedResult
{
   cursor: hand;
   cursor: pointer; 
}

.result
{
   width:150px;
   height:150px;
   border:0;
}

.inputForms
{
   display:inline;
   clear:none;
}

label
{
	float:left;
	font-weight:bold;
	width:10em;
}

.Row
{
	float:left;
	clear:both;
	margin-bottom:1em;
	width:100%;
}

.Row input, .Row select, .Row textarea
{
	width:15em;
}

.Row textarea
{
	height:6em;
}