#!/usr/bin/env python

from distutils.core import setup

setup(name='GrabzIt',
      version='3.2.1',
      author='GrabzIt',
      author_email='support@grabz.it',
      url='https://grabz.it/api/python/',
      license='MIT Licence',
      description='GrabzIt enables allows you to programmatically convert web pages and HTML into images, DOCX documents, PDFs, CSVs and spreadsheets. Additionally GrabzIt allows you to convert online videos into animated GIFs',
      packages=['GrabzIt']      
)
